/*
** DBC/GETIMG.REXX
**
** $VER: DBC/GETIMG.REXX 1.0.0 (17.03.95)
**
** This ARexx script is for use with Hollywood FX.  
** It will extract the first frame from a Digital Broadcaster
** J-Stream file.
**
** This script requires ADPro v2.5.0 (or higher).
**
** Copyright  1994 Synergy International, Incorporated
** All Rights Reserved
** 
** The following copyright notice applies to the Locate-ADPro
** code included in this script:
**
** Copyright  1991-1993 ASDG, Incorporated
** All Rights Reserved
*/

OPTIONS RESULTS

/******************************************************/
/* User Definitions                                   */
/******************************************************/

Extracter = "Producer:Tools/ExtractJPEG"

/******************************************************/
/* Start of Script                                    */
/******************************************************/

/*** Parse arguments sent from Hollywood FX ***/

PARSE ARG stream ',' frame ',' outname


/*** Check if ADPro is loaded, if not try to load ***/

CALL Locate_ADPro

/*** Could not load ADPro, exit script ***/

IF (RESULT = 0) THEN
  EXIT 10

/******************************************************************************/

/*** Get names of each field of stream ***/

Field0 = LEFT(stream, LENGTH(stream) - 4) || ".JF0"
Field1 = LEFT(stream, LENGTH(stream) - 4) || ".JF1"

/*** Extract first frame to get frame size ***/

ADDRESS "COMMAND"
Extracter stream 0

/*** Set all values for JPEG Loader in ADPro ***/

ADDRESS "ADPro"
LOADER "JPEG" Field0

XSIZE
Horz = ADPRO_RESULT
IF (Horz ~= 720) THEN DO
  TempField = Field0
  Field0 = Field1
  Field1 = TempField
  END
  
YSIZE
Vert = ADPRO_RESULT
Vert = Vert * 2

/*** Extract the frame as a JPEG image ***/

ADDRESS "COMMAND"
Extracter stream 0

/*** Now use ADPro to convert it to an IFF24 image ***/

ADDRESS "ADPro"
LOAD_TYPE REPLACE
LOADER "BACKDROP" "XXX" WIDTH Horz HEIGHT Vert "COLOR"
LOAD_TYPE COMPOSE
LOADER "JPEG" Field1 0 0
LOADER "JPEG" Field0 0 (Vert / 2)
OPERATOR "INTERLACE"
SAVER "IFF" outname "RAW"

EXIT (0)

/******************************************************************************/
  
/*** Locate_ADPro function provided by ASDG, Inc. ***/

Locate_ADPro:
	Max_Seconds_To_Load = 60
	Flag = 0
	LibName = 'rexxsupport.library'

	IF (POS( LibName, SHOW( 'Libraries' ) ) = 0) THEN
		ADDLIB( LibName, 0, -30, 0 )
	IF (POS( LibName, SHOW( 'Libraries' ) ) = 0) THEN
		RETURN 0

	IF (STATEF( 'ADPRO:' ) = "") THEN
		RETURN 0

	TIME( 'R' )
	DO WHILE (TIME( 'E' ) < Max_Seconds_To_Load) & (POS( 'ADPro', SHOW( 'Ports' ) ) = 0)
		IF (Flag = 0) THEN DO
			/* Set whatever command line arguments you want. */
			ADDRESS COMMAND 'Run < NIL: > NIL: ADPRO:ADPro MINIMIZED'
			Flag = 1
		END
		ADDRESS COMMAND 'Wait 1'
	END
	IF (POS( 'ADPro', SHOW( 'Ports' ) ) = 0) THEN
		RETURN 0
	ELSE
		RETURN 1
